==> common-1.3.0.8-sources.jar: cn/gtmap/gtc/workflow/domain/define/ProcessDefinedDto.java <==
package cn.gtmap.gtc.workflow.domain.define;

import java.io.Serializable;


/**
 * 流程定义的对外Bean
 */
public class ProcessDefinedDto implements Serializable {

    private static final long serialVersionUID = -7970346837382645532L;

    private String id;

    private String category;

    private String name;

    private String key;

    private Integer version;

    private String deploymentId;

    private String description;

    private Integer suspensionState;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getCategory() {
        return category;
    }

    public void setCategory(String category) {
        this.category = category;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getKey() {
        return key;
    }

    public void setKey(String key) {
        this.key = key;
    }

    public Integer getVersion() {
        return version;
    }

    public void setVersion(Integer version) {
        this.version = version;
    }

    public String getDeploymentId() {
        return deploymentId;
    }

    public void setDeploymentId(String deploymentId) {
        this.deploymentId = deploymentId;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Integer getSuspensionState() {
        return suspensionState;
    }

    public void setSuspensionState(Integer suspensionState) {
        this.suspensionState = suspensionState;
    }
}

==> common-1.3.30-sources.jar: cn/gtmap/gtc/workflow/domain/define/ProcessDefinedDto.java <==
package cn.gtmap.gtc.workflow.domain.define;

import java.io.Serializable;


/**
 * 流程定义的对外Bean
 */
public class ProcessDefinedDto implements Serializable {

    private static final long serialVersionUID = -7970346837382645532L;

    private String id;

    private String category;

    private String name;

    private String key;

    private Integer version;

    private String deploymentId;

    private String description;

    private Integer suspensionState;

    private String abbreviation;

    private String bgColor;

    private Integer sort; //排序

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getCategory() {
        return category;
    }

    public void setCategory(String category) {
        this.category = category;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getKey() {
        return key;
    }

    public void setKey(String key) {
        this.key = key;
    }

    public Integer getVersion() {
        return version;
    }

    public void setVersion(Integer version) {
        this.version = version;
    }

    public String getDeploymentId() {
        return deploymentId;
    }

    public void setDeploymentId(String deploymentId) {
        this.deploymentId = deploymentId;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Integer getSuspensionState() {
        return suspensionState;
    }

    public void setSuspensionState(Integer suspensionState) {
        this.suspensionState = suspensionState;
    }

    public String getAbbreviation() {
        return abbreviation;
    }

    public void setAbbreviation(String abbreviation) {
        this.abbreviation = abbreviation;
    }

    public String getBgColor() {
        return bgColor;
    }

    public void setBgColor(String bgColor) {
        this.bgColor = bgColor;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }
}
